@@ -1,5 +1,5 @@
 ﻿/*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -84,7 +84,7 @@ bool KNoteCollectionDisplayProxyModel::setData(const QModelIndex &index, const Q
             const Akonadi::Collection collection
                 = data(index, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
             mDisplayCollection[collection] = (value == Qt::Checked);
-            emit dataChanged(index, index);
+            Q_EMIT dataChanged(index, index);
             return true;
         }
     }
